# @api private
class harbor::config (
  $cfg_version,
  $hostname,
  $ui_url_protocol,
  $max_job_workers,
  $absolute_url,
  $customize_crt,
  $ssl_cert,
  $ssl_cert_key,
  $secretkey_path,
  $admiral_url,
  $external_url,
  $log_level,
  $log_rotate_count,
  $log_rotate_size,
  $log_location,
  $http_proxy,
  $https_proxy,
  $no_proxy,
  $data_volume,
  $email_identity,
  $email_server,
  $email_server_port,
  $email_username,
  $email_password,
  $email_from,
  $email_ssl,
  $email_insecure,
  $harbor_admin_password,
  $auth_mode,
  $ldap_url,
  $ldap_searchdn,
  $ldap_search_pwd,
  $ldap_basedn,
  $ldap_filter,
  $ldap_uid,
  $ldap_scope,
  $ldap_timeout,
  $ldap_verify_cert,
  $ldap_group_basedn,
  $ldap_group_filter,
  $ldap_group_gid,
  $ldap_group_scope,
  $ldap_group_admin_dn,
  $self_registration,
  $token_expiration,
  $project_creation_restriction,
  $db_host,
  $db_password,
  $db_port,
  $db_user,
  $db_max_idle_connections,
  $db_max_open_conns,
  $external_redis,
  $redis_host,
  $redis_port,
  $redis_password,
  $redis_registry_db_index,
  $redis_jobservice_db_index,
  $redis_chartmuseum_db_index,
  $redis_clair_db_index,
  $clair_db_host,
  $clair_db_password,
  $clair_db_port,
  $clair_db_username,
  $clair_db,
  $clair_updaters_interval,
  $uaa_endpoint,
  $uaa_clientid,
  $uaa_clientsecret,
  $uaa_verify_cert,
  $uaa_ca_cert,
  $registry_storage_provider_name,
  $registry_storage_provider_config,
  $registry_custom_ca_bundle,
  $reload_config,
  $skip_reload_env_pattern,
  $webhook_job_max_retry,
){

  assert_private()

  $_config = {
    'cfg_version'                      => $cfg_version,
    'hostname'                         => $hostname,
    'ui_url_protocol'                  => $ui_url_protocol,
    'max_job_workers'                  => $max_job_workers,
    'absolute_url'                     => $absolute_url,
    'customize_crt'                    => $customize_crt,
    'ssl_cert'                         => $ssl_cert,
    'ssl_cert_key'                     => $ssl_cert_key,
    'secretkey_path'                   => $secretkey_path,
    'log_rotate_count'                 => $log_rotate_count,
    'log_rotate_size'                  => $log_rotate_size,
    'http_proxy'                       => $http_proxy,
    'https_proxy'                      => $https_proxy,
    'no_proxy'                         => $no_proxy,
    'harbor_admin_password'            => $harbor_admin_password,
    'db_host'                          => $db_host,
    'db_password'                      => $db_password,
    'db_port'                          => $db_port,
    'db_user'                          => $db_user,
    'redis_host'                       => $redis_host,
    'redis_port'                       => $redis_port,
    'redis_password'                   => $redis_password,
    'clair_db_host'                    => $clair_db_host,
    'clair_db_password'                => $clair_db_password,
    'clair_db_port'                    => $clair_db_port,
    'clair_db_username'                => $clair_db_username,
    'clair_db'                         => $clair_db,
    'clair_updaters_interval'          => $clair_updaters_interval,
    'uaa_ca_cert'                      => $uaa_ca_cert,
    'registry_storage_provider_name'   => $registry_storage_provider_name,
    'registry_storage_provider_config' => $registry_storage_provider_config,
    'registry_custom_ca_bundle'        => $registry_custom_ca_bundle,
    'reload_config'                    => $reload_config,
    'skip_reload_env_pattern'          => $skip_reload_env_pattern,
    'external_url'                     => $external_url,
    'log_level'                        => $log_level,
    'log_location'                     => $log_location,
    'data_volume'                      => $data_volume,
    'db_max_idle_connections'          => $db_max_idle_connections,
    'db_max_open_conns'                => $db_max_open_conns,
    'external_redis'                   => $external_redis,
    'redis_registry_db_index'          => $redis_registry_db_index,
    'redis_jobservice_db_index'        => $redis_jobservice_db_index,
    'redis_chartmuseum_db_index'       => $redis_chartmuseum_db_index,
    'redis_clair_db_index'             => $redis_clair_db_index,
    'webhook_job_max_retry'            => $webhook_job_max_retry,
  }

  file { '/opt/harbor/harbor.yml':
    owner   => 'root',
    group   => 'root',
    mode    => '0644',
    content => epp('harbor/harbor.yml.epp', $_config),
  }

  exec { 'migrate_cfg':
    cwd         => '/opt/harbor',
    command     => "/usr/bin/docker run -it --rm -v harbor.yml:/harbor-migration/harbor-cfg/harbor.yml -v harbor.yml:/harbor-migration/harbor-cfg-out/harbor.yml goharbor/harbor-migrator:${cfg_version} --cfg up",
    logoutput   => true,
    refreshonly => true,
  }

}
